]> git.ipfire.org Git - ipfire-2.x.git/blobdiff - make.sh
make.sh: Fit more processes into memory
[ipfire-2.x.git] / make.sh
diff --git a/make.sh b/make.sh
index 39a1c5380841a3ada47c7d156c5080fe90747064..e28819f9b3333a1971e37dd90b677aad1309f5c3 100755 (executable)
--- a/make.sh
+++ b/make.sh
@@ -202,9 +202,9 @@ configure_build() {
 
        # Determine parallelism
        # We assume that each process consumes about
# 192MB of memory. Therefore we find out how
        # many processes fit into memory.
-       local mem_max=$(( ${SYSTEM_MEMORY} / 192 ))
+       local mem_max=$(( ${SYSTEM_MEMORY} / 128 ))
        local cpu_max=$(( ${SYSTEM_PROCESSORS} + 1 ))
 
        local parallelism
@@ -202,9 +202,9 @@ configure_build() {
        # Determine parallelism
        # We assume that each process consumes about
-       # 192MB of memory. Therefore we find out how
+       # 128MB of memory. Therefore we find out how
        # many processes fit into memory.